From b7b6c6c42bafea9cde0363506dbe311f987c4844 Mon Sep 17 00:00:00 2001
From: admtracksteel
Date: Fri, 5 Jun 2026 13:58:02 +0000
Subject: [PATCH] Renomeando app no frontend para PedaGog
---
public/app.js | 6 +++---
public/index.html | 20 ++++++++++----------
public/manifest.json | 6 +++---
3 files changed, 16 insertions(+), 16 deletions(-)
diff --git a/public/index.html b/public/index.html
index 56af47a..5c95e18 100644
--- a/public/index.html
+++ b/public/index.html
@@ -4,15 +4,15 @@
-
+
-
+
- Camila AI
+ PedaGog
@@ -262,7 +262,7 @@
-
+
- Camila AI pode cometer erros. Considere verificar informações importantes.
+ PedaGog pode cometer erros. Considere verificar informações importantes.
@@ -654,7 +654,7 @@
diff --git a/public/app.js b/public/app.js
index d2faa7f..a696d6d 100644
--- a/public/app.js
+++ b/public/app.js
@@ -1917,7 +1917,7 @@ const initApp = () => {
renderHistory();
}
// Criar container para a resposta do bot (Camila AI) na tela
const botRow = document.createElement('div');
botRow.className = 'message-row assistant';
@@ -2255,7 +2255,7 @@ const initApp = () => {
- Desculpe, ocorreu um erro ao obter resposta da Camila AI. Por favor, tente novamente.
+ Desculpe, ocorreu um erro ao obter resposta da PedaGog. Por favor, tente novamente.
`;
scrollToBottom();
@@ -4472,7 +4472,7 @@ const initApp = () => {
doc.setFont('helvetica', 'italic');
doc.setFontSize(9);
doc.setTextColor(148, 163, 184);
- doc.text(`Criado com Camila AI - Quadro ${panel.panel_number} de ${generatedPanelsData.length}`, 297, 815, { align: 'center' });
+ doc.text(`Criado com PedaGog - Quadro ${panel.panel_number} de ${generatedPanelsData.length}`, 297, 815, { align: 'center' });
}
doc.save(`quadrinhos_${title.replace(/\s+/g, '_').toLowerCase()}.pdf`);
@@ -1917,7 +1917,7 @@ const initApp = () => {
renderHistory();
}
- // Criar container para a resposta do bot (Camila AI) na tela
+ // Criar container para a resposta do bot (PedaGog) na tela
const botRow = document.createElement('div');
botRow.className = 'message-row assistant';